"""Setup file for package."""
import setuptools

# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setuptools.setup(
    name="cronaion",
    version="1.0.4",
    author="Chris Reusch",
    description="Scheduler for python tasks.",
    packages=["cronaion"],
    install_requires=[
        "cron_converter",
    ],
    long_description=long_description,
    long_description_content_type='text/markdown'
)



"""Examples for Aion."""

from cronaion import Aion

watcher = Aion()


@watcher.watch("1 3 * * 0")
def check_the_mail():
    print("I will run at 03:01 every Sunday.")


@watcher.watch("*/1 * * * *")
def blink_my_eyes():
    print("I will run every 60 seconds.")


if __name__ == "__main__":
    watcher.start()
